
# Type: id_prefixes


the identifier of this class or slot must begin with one of the URIs referenced by this prefix

URI: [meta:id_prefixes](https://w3id.org/biolink/biolinkml/meta/id_prefixes)


## Domain and Range

[Element](Element.md) ->  <sub>0..*</sub> [Ncname](types/Ncname.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)
